Here are the release notes based on the provided commit log:

## Version 0.1.2

This release includes new model names for llamabot and an update to its dependencies.

### New Features

- Added 'qwen' and 'tinydolphin' to the list of llamabot model names and updated dependencies to include 'pydantic' (21c1492) (Eric Ma)
- Bumped version number from 0.1.1 to 0.1.2 (76b9b4) (github-actions)

### Bug Fixes

No bug fixes were included in this release.

### Deprecations

No deprecations were included in this release.

Note: The commit `cd04ed38` is not included in the release notes as it only added release notes for version 0.1.1.
